import * as i0 from '@angular/core';
import { InjectionToken, Component, ChangeDetectionStrategy, Optional, Inject, Input, NgModule } from '@angular/core';
import { observeResize } from 'angular-pharkas/observe-resize';
import { PharkasComponent } from 'angular-pharkas';
import { Observable, combineLatest, merge, of } from 'rxjs';
import { first, switchMap, delay, debounceTime, shareReplay } from 'rxjs/operators';
import * as _Highcharts from 'highcharts';
import HighchartsStock from 'highcharts/modules/stock';

// ES Module imports are immutable proxies, so we need a mutable shallow clone
const H = Object.assign({}, _Highcharts);
HighchartsStock(H);
const Highcharts = H;
const HIGHCHARTS = new InjectionToken('highcharts');

class ChartComponent extends PharkasComponent {
    set options(value) {
        this.setInput('options', value);
    }
    set oneToOne(value) {
        this.setInput('oneToOne', value);
    }
    constructor(ref, host, highcharts) {
        super(ref);
        const options = this.useInput('options');
        const chart = options.pipe(first(), switchMap((options) => {
            return new Observable((observer) => {
                const chart = (highcharts !== null && highcharts !== void 0 ? highcharts : Highcharts).chart(host.nativeElement, options, (chart) => observer.next(chart));
                return () => chart.destroy();
            });
        }));
        const resize = combineLatest([
            chart,
            merge(of([]).pipe(delay(3000 /* ms */)), observeResize(host)),
        ]).pipe(debounceTime(150 /* ms */));
        this.bindEffect(resize, ([chart]) => {
            chart.reflow();
        });
        const oneToOne = this.useInput('oneToOne', false);
        this.bindEffect(combineLatest([options, chart, oneToOne]), ([options, chart, oneToOne]) => {
            chart.update(options, true, oneToOne);
        });
    }
}
ChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: ChartComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ElementRef }, { token: HIGHCHARTS, optional: true }], target: i0.ɵɵFactoryTarget.Component });
ChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: ChartComponent, selector: "pharkas-chart", inputs: { options: "options", oneToOne: "oneToOne" }, usesInheritance: true, ngImport: i0, template: "", styles: [":host{display:block;width:100%;height:100%}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: ChartComponent, decorators: [{
            type: Component,
            args: [{ selector: 'pharkas-chart', changeDetection: ChangeDetectionStrategy.OnPush, template: "", styles: [":host{display:block;width:100%;height:100%}\n"] }]
        }], ctorParameters: function () {
        return [{ type: i0.ChangeDetectorRef }, { type: i0.ElementRef }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [HIGHCHARTS]
                    }] }];
    }, propDecorators: { options: [{
                type: Input
            }], oneToOne: [{
                type: Input
            }] } });

class StockChartComponent extends PharkasComponent {
    set options(value) {
        this.setInput('options', value);
    }
    set oneToOne(value) {
        this.setInput('oneToOne', value);
    }
    constructor(ref, host, highcharts) {
        super(ref);
        const options = this.useInput('options');
        const chart = options.pipe(first(), switchMap((options) => {
            return new Observable((observer) => {
                const chart = (highcharts !== null && highcharts !== void 0 ? highcharts : Highcharts).stockChart(host.nativeElement, options);
                observer.next(chart);
                return () => chart.destroy();
            });
        }), shareReplay(1));
        const resize = combineLatest([
            chart,
            merge(of([]).pipe(delay(3000 /* ms */)), observeResize(host)),
        ]).pipe(debounceTime(150 /* ms */));
        this.bindEffect(resize, ([chart]) => {
            chart.reflow();
        });
        const oneToOne = this.useInput('oneToOne', false);
        this.bindEffect(combineLatest([options, chart, oneToOne]), ([options, chart, oneToOne]) => {
            chart.update(options, true, oneToOne);
        });
    }
}
StockChartComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: StockChartComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ElementRef }, { token: HIGHCHARTS, optional: true }], target: i0.ɵɵFactoryTarget.Component });
StockChartComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.9", type: StockChartComponent, selector: "pharkas-stockchart", inputs: { options: "options", oneToOne: "oneToOne" }, usesInheritance: true, ngImport: i0, template: "", styles: [":host{display:block;width:100%;height:100%}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: StockChartComponent, decorators: [{
            type: Component,
            args: [{ selector: 'pharkas-stockchart', changeDetection: ChangeDetectionStrategy.OnPush, template: "", styles: [":host{display:block;width:100%;height:100%}\n"] }]
        }], ctorParameters: function () {
        return [{ type: i0.ChangeDetectorRef }, { type: i0.ElementRef }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [HIGHCHARTS]
                    }] }];
    }, propDecorators: { options: [{
                type: Input
            }], oneToOne: [{
                type: Input
            }] } });

class PharkasHighchartsModule {
}
PharkasHighchartsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: PharkasHighchartsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
PharkasHighchartsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.9", ngImport: i0, type: PharkasHighchartsModule, declarations: [ChartComponent, StockChartComponent], exports: [ChartComponent, StockChartComponent] });
PharkasHighchartsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: PharkasHighchartsModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.9", ngImport: i0, type: PharkasHighchartsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ChartComponent, StockChartComponent],
                    exports: [ChartComponent, StockChartComponent],
                }]
        }] });

/*
 * Public API Surface of angular-pharkas-highcharts
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ChartComponent, HIGHCHARTS, Highcharts, PharkasHighchartsModule, StockChartComponent };
//# sourceMappingURL=angular-pharkas-highcharts.mjs.map
